==> ask_sdk_model-1.6.1-py2.py3-none-any.whl: ask_sdk_model/interfaces/geolocation/altitude.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class Altitude(object):
    """
    An object containing the altitude information of the device.


    :param altitude_in_meters: A double representing the altitude of the device in meters.
    :type altitude_in_meters: (optional) float
    :param accuracy_in_meters: A double representing the accuracy of the altitude measurement in meters.
    :type accuracy_in_meters: (optional) float

    """
    deserialized_types = {
        'altitude_in_meters': 'float',
        'accuracy_in_meters': 'float'
    }

    attribute_map = {
        'altitude_in_meters': 'altitudeInMeters',
        'accuracy_in_meters': 'accuracyInMeters'
    }

    def __init__(self, altitude_in_meters=None, accuracy_in_meters=None):
        # type: (Optional[float], Optional[float]) -> None
        """An object containing the altitude information of the device.

        :param altitude_in_meters: A double representing the altitude of the device in meters.
        :type altitude_in_meters: (optional) float
        :param accuracy_in_meters: A double representing the accuracy of the altitude measurement in meters.
        :type accuracy_in_meters: (optional) float
        """
        self.__discriminator_value = None

        self.altitude_in_meters = altitude_in_meters
        self.accuracy_in_meters = accuracy_in_meters

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Altitude):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask_sdk_model-1.10.0-py2.py3-none-any.whl: ask_sdk_model/interfaces/geolocation/altitude.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class Altitude(object):
    """
    An object containing the altitude information of the device.


    :param altitude_in_meters: A double representing the altitude of the device in meters.
    :type altitude_in_meters: (optional) float
    :param accuracy_in_meters: A double representing the accuracy of the altitude measurement in meters.
    :type accuracy_in_meters: (optional) float

    """
    deserialized_types = {
        'altitude_in_meters': 'float',
        'accuracy_in_meters': 'float'
    }  # type: Dict

    attribute_map = {
        'altitude_in_meters': 'altitudeInMeters',
        'accuracy_in_meters': 'accuracyInMeters'
}  # type: Dict

    def __init__(self, altitude_in_meters=None, accuracy_in_meters=None):
        # type: (Optional[float], Optional[float]) -> None
        """An object containing the altitude information of the device.

        :param altitude_in_meters: A double representing the altitude of the device in meters.
        :type altitude_in_meters: (optional) float
        :param accuracy_in_meters: A double representing the accuracy of the altitude measurement in meters.
        :type accuracy_in_meters: (optional) float
        """
        self.__discriminator_value = None  # type: str

        self.altitude_in_meters = altitude_in_meters
        self.accuracy_in_meters = accuracy_in_meters

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Altitude):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
